==> on_audio_edit-1.0.0.tar.gz: android/src/main/kotlin/com/lucasjosino/on_audio_edit/utils/OnTagsProjections.kt <==
package com.lucasjosino.on_audio_edit.utils

import org.jaudiotagger.tag.FieldKey

fun getProjection() : Array<FieldKey> = projection
fun getAllProjection() : Array<FieldKey> = allProjection

private var projection = arrayOf(
        FieldKey.ALBUM_ARTIST,
        FieldKey.ARTIST,
        FieldKey.ARTISTS,
        FieldKey.BPM,
        FieldKey.COMPOSER,
        FieldKey.COUNTRY,
        FieldKey.GENRE,
//            FieldKey.ID,
        FieldKey.ISRC,
        FieldKey.KEY,
        FieldKey.LANGUAGE,
        FieldKey.LYRICS,
        FieldKey.ORIGINAL_ALBUM,
        FieldKey.ORIGINAL_ARTIST,
        FieldKey.ORIGINAL_LYRICIST,
        FieldKey.ORIGINAL_YEAR,
        FieldKey.PRODUCER,
        FieldKey.QUALITY,
        FieldKey.RATING,
        FieldKey.RECORD_LABEL,
        FieldKey.SUBTITLE,
        FieldKey.TAGS,
        FieldKey.TEMPO,
        FieldKey.TITLE,
        FieldKey.TRACK,
        FieldKey.YEAR
)
private var allProjection = arrayOf(
        FieldKey.ACOUSTID_FINGERPRINT,
        FieldKey.ACOUSTID_ID,
        FieldKey.ALBUM,
        FieldKey.ALBUM_ARTIST,
        FieldKey.ALBUM_ARTIST_SORT,
        FieldKey.ALBUM_SORT,
        FieldKey.AMAZON_ID,
        FieldKey.ARRANGER,
        FieldKey.ARTIST,
        FieldKey.ARTIST_SORT,
        FieldKey.ARTISTS,
        FieldKey.BARCODE,
        FieldKey.BPM,
        FieldKey.CATALOG_NO,
        FieldKey.COMMENT,
        FieldKey.COMPOSER,
        FieldKey.COMPOSER_SORT,
        FieldKey.CONDUCTOR,
        FieldKey.COUNTRY,
        FieldKey.COVER_ART,
        FieldKey.CUSTOM1,
        FieldKey.CUSTOM2,
        FieldKey.CUSTOM3,
        FieldKey.CUSTOM4,
        FieldKey.CUSTOM5,
        FieldKey.DISC_NO,
        FieldKey.DISC_SUBTITLE,
        FieldKey.DISC_TOTAL,
        FieldKey.DJMIXER,
        FieldKey.ENCODER,
        FieldKey.ENGINEER,
        FieldKey.FBPM,
        FieldKey.GENRE,
        FieldKey.GROUPING,
        FieldKey.ISRC,
        FieldKey.IS_COMPILATION,
        FieldKey.KEY,
        FieldKey.LANGUAGE,
        FieldKey.LYRICIST,
        FieldKey. LYRICS,
        FieldKey.MEDIA,
        FieldKey.MIXER,
        FieldKey.MOOD,
        FieldKey.MUSICBRAINZ_ARTISTID,
        FieldKey.MUSICBRAINZ_DISC_ID,
        FieldKey.MUSICBRAINZ_ORIGINAL_RELEASE_ID,
        FieldKey.MUSICBRAINZ_RELEASEARTISTID,
        FieldKey.MUSICBRAINZ_RELEASEID,
        FieldKey.MUSICBRAINZ_RELEASE_COUNTRY,
        FieldKey.MUSICBRAINZ_RELEASE_GROUP_ID,
        FieldKey.MUSICBRAINZ_RELEASE_STATUS,
        FieldKey.MUSICBRAINZ_RELEASE_TRACK_ID,
        FieldKey.MUSICBRAINZ_RELEASE_TYPE,
        FieldKey.MUSICBRAINZ_TRACK_ID,
        FieldKey.MUSICBRAINZ_WORK_ID,
        FieldKey.MUSICIP_ID,
        FieldKey.OCCASION,
        FieldKey.ORIGINAL_ALBUM,
        FieldKey.ORIGINAL_ARTIST,
        FieldKey.ORIGINAL_LYRICIST,
        FieldKey.ORIGINAL_YEAR,
        FieldKey.QUALITY,
        FieldKey.PRODUCER,
        FieldKey.RATING,
        FieldKey.RECORD_LABEL,
        FieldKey.REMIXER,
        FieldKey.SCRIPT,
        FieldKey.SUBTITLE,
        FieldKey.TAGS,
        FieldKey.TEMPO,
        FieldKey.TITLE,
        FieldKey.TITLE_SORT,
        FieldKey.TRACK,
        FieldKey.TRACK_TOTAL,
        FieldKey.URL_DISCOGS_ARTIST_SITE,
        FieldKey.URL_DISCOGS_RELEASE_SITE,
        FieldKey.URL_LYRICS_SITE,
        FieldKey.URL_OFFICIAL_ARTIST_SITE,
        FieldKey.URL_OFFICIAL_RELEASE_SITE,
        FieldKey.URL_WIKIPEDIA_ARTIST_SITE,
        FieldKey.URL_WIKIPEDIA_RELEASE_SITE,
        FieldKey.YEAR
)

// Extras:

// All Tags
// {
//   ACOUSTID_FINGERPRINT,
//   ACOUSTID_ID,
//   ALBUM,
//   ALBUM_ARTIST_SORT,
//   ALBUM_SORT,
//   AMAZON_ID,
//   ARRANGER,
//   ARTIST_SORT,
//   BARCODE,
//   CATALOG_NO,
//   COMMENT,
//   COMPOSER_SORT,
//   CONDUCTOR,
//   COVER_ART,
//   CUSTOM1,
//   CUSTOM2,
//   CUSTOM3,
//   CUSTOM4,
//   CUSTOM5,
//   DISC_NO,
//   DISC_SUBTITLE,
//   DISC_TOTAL,
//   DJMIXER,
//   ENCODER,
//   ENGINEER,
//   FBPM,
//   GROUPING,
//   IS_COMPILATION,
//   LYRICIST,
//   MEDIA,
//   MIXER,
//   MOOD,
//   MUSICBRAINZ_ARTISTID,
//   MUSICBRAINZ_DISC_ID,
//   MUSICBRAINZ_ORIGINAL_RELEASE_ID,
//   MUSICBRAINZ_RELEASEARTISTID,
//   MUSICBRAINZ_RELEASEID,
//   MUSICBRAINZ_RELEASE_COUNTRY,
//   MUSICBRAINZ_RELEASE_GROUP_ID,
//   MUSICBRAINZ_RELEASE_STATUS,
//   MUSICBRAINZ_RELEASE_TRACK_ID,
//   MUSICBRAINZ_RELEASE_TYPE,
//   MUSICBRAINZ_TRACK_ID,
//   MUSICBRAINZ_WORK_ID,
//   MUSICIP_ID,
//   OCCASION,
//   REMIXER,
//   SCRIPT,
//   TITLE_SORT,
//   TRACK_TOTAL,
//   URL_DISCOGS_ARTIST_SITE,
//   URL_DISCOGS_RELEASE_SITE,
//   URL_LYRICS_SITE,
//   URL_OFFICIAL_ARTIST_SITE,
//   URL_OFFICIAL_RELEASE_SITE,
//   URL_WIKIPEDIA_ARTIST_SITE,
//   URL_WIKIPEDIA_RELEASE_SITE,
// }

==> on_audio_edit-1.1.0.tar.gz: android/src/main/kotlin/com/lucasjosino/on_audio_edit/utils/OnTagsProjections.kt <==
package com.lucasjosino.on_audio_edit.utils

import org.jaudiotagger.tag.FieldKey

fun getProjection() : Array<FieldKey> = projection
fun getAllProjection() : Array<FieldKey> = allProjection

private var projection = arrayOf(
        FieldKey.ALBUM_ARTIST,
        FieldKey.ARTIST,
        FieldKey.ARTISTS,
        FieldKey.BPM,
//            FieldKey.BITRATE, 4
//            FieldKey.CHANNELS, 5
        FieldKey.COMPOSER,
        FieldKey.COUNTRY,
        FieldKey.COVER_ART,
//            FieldKey.FIRST_ARTWORK, 9
//            FieldKey.FORMAT, 10
        FieldKey.GENRE,
        FieldKey.ISRC,
        FieldKey.KEY,
        FieldKey.LANGUAGE,
//            FieldKey.LENGTH, 15
        FieldKey.LYRICS,
        FieldKey.ORIGINAL_ALBUM,
        FieldKey.ORIGINAL_ARTIST,
        FieldKey.ORIGINAL_LYRICIST,
        FieldKey.ORIGINAL_YEAR,
        FieldKey.PRODUCER,
        FieldKey.QUALITY,
        FieldKey.RATING,
        FieldKey.RECORD_LABEL,
//            FieldKey.SAMPLE_RATE, 25
        FieldKey.SUBTITLE,
        FieldKey.TAGS,
        FieldKey.TEMPO,
        FieldKey.TITLE,
        FieldKey.TRACK,
//            FieldKey.TYPE, 31
        FieldKey.YEAR
)
private var allProjection = arrayOf(
        FieldKey.ACOUSTID_FINGERPRINT,
        FieldKey.ACOUSTID_ID,
        FieldKey.ALBUM,
        FieldKey.ALBUM_ARTIST,
        FieldKey.ALBUM_ARTIST_SORT,
        FieldKey.ALBUM_SORT,
        FieldKey.AMAZON_ID,
        FieldKey.ARRANGER,
        FieldKey.ARTIST,
        FieldKey.ARTIST_SORT,
        FieldKey.ARTISTS,
        FieldKey.BARCODE,
        FieldKey.BPM,
        FieldKey.CATALOG_NO,
        FieldKey.COMMENT,
        FieldKey.COMPOSER,
        FieldKey.COMPOSER_SORT,
        FieldKey.CONDUCTOR,
        FieldKey.COUNTRY,
        FieldKey.COVER_ART,
        FieldKey.CUSTOM1,
        FieldKey.CUSTOM2,
        FieldKey.CUSTOM3,
        FieldKey.CUSTOM4,
        FieldKey.CUSTOM5,
        FieldKey.DISC_NO,
        FieldKey.DISC_SUBTITLE,
        FieldKey.DISC_TOTAL,
        FieldKey.DJMIXER,
        FieldKey.ENCODER,
        FieldKey.ENGINEER,
        FieldKey.FBPM,
        FieldKey.GENRE,
        FieldKey.GROUPING,
        FieldKey.ISRC,
        FieldKey.IS_COMPILATION,
        FieldKey.KEY,
        FieldKey.LANGUAGE,
        FieldKey.LYRICIST,
        FieldKey. LYRICS,
        FieldKey.MEDIA,
        FieldKey.MIXER,
        FieldKey.MOOD,
        FieldKey.MUSICBRAINZ_ARTISTID,
        FieldKey.MUSICBRAINZ_DISC_ID,
        FieldKey.MUSICBRAINZ_ORIGINAL_RELEASE_ID,
        FieldKey.MUSICBRAINZ_RELEASEARTISTID,
        FieldKey.MUSICBRAINZ_RELEASEID,
        FieldKey.MUSICBRAINZ_RELEASE_COUNTRY,
        FieldKey.MUSICBRAINZ_RELEASE_GROUP_ID,
        FieldKey.MUSICBRAINZ_RELEASE_STATUS,
        FieldKey.MUSICBRAINZ_RELEASE_TRACK_ID,
        FieldKey.MUSICBRAINZ_RELEASE_TYPE,
        FieldKey.MUSICBRAINZ_TRACK_ID,
        FieldKey.MUSICBRAINZ_WORK_ID,
        FieldKey.MUSICIP_ID,
        FieldKey.OCCASION,
        FieldKey.ORIGINAL_ALBUM,
        FieldKey.ORIGINAL_ARTIST,
        FieldKey.ORIGINAL_LYRICIST,
        FieldKey.ORIGINAL_YEAR,
        FieldKey.QUALITY,
        FieldKey.PRODUCER,
        FieldKey.RATING,
        FieldKey.RECORD_LABEL,
        FieldKey.REMIXER,
        FieldKey.SCRIPT,
        FieldKey.SUBTITLE,
        FieldKey.TAGS,
        FieldKey.TEMPO,
        FieldKey.TITLE,
        FieldKey.TITLE_SORT,
        FieldKey.TRACK,
        FieldKey.TRACK_TOTAL,
        FieldKey.URL_DISCOGS_ARTIST_SITE,
        FieldKey.URL_DISCOGS_RELEASE_SITE,
        FieldKey.URL_LYRICS_SITE,
        FieldKey.URL_OFFICIAL_ARTIST_SITE,
        FieldKey.URL_OFFICIAL_RELEASE_SITE,
        FieldKey.URL_WIKIPEDIA_ARTIST_SITE,
        FieldKey.URL_WIKIPEDIA_RELEASE_SITE,
        FieldKey.YEAR
)

// Extras:

// All Tags
// {
//   ACOUSTID_FINGERPRINT,
//   ACOUSTID_ID,
//   ALBUM,
//   ALBUM_ARTIST_SORT,
//   ALBUM_SORT,
//   AMAZON_ID,
//   ARRANGER,
//   ARTIST_SORT,
//   BARCODE,
//   CATALOG_NO,
//   COMMENT,
//   COMPOSER_SORT,
//   CONDUCTOR,
//   COVER_ART,
//   CUSTOM1,
//   CUSTOM2,
//   CUSTOM3,
//   CUSTOM4,
//   CUSTOM5,
//   DISC_NO,
//   DISC_SUBTITLE,
//   DISC_TOTAL,
//   DJMIXER,
//   ENCODER,
//   ENGINEER,
//   FBPM,
//   GROUPING,
//   IS_COMPILATION,
//   LYRICIST,
//   MEDIA,
//   MIXER,
//   MOOD,
//   MUSICBRAINZ_ARTISTID,
//   MUSICBRAINZ_DISC_ID,
//   MUSICBRAINZ_ORIGINAL_RELEASE_ID,
//   MUSICBRAINZ_RELEASEARTISTID,
//   MUSICBRAINZ_RELEASEID,
//   MUSICBRAINZ_RELEASE_COUNTRY,
//   MUSICBRAINZ_RELEASE_GROUP_ID,
//   MUSICBRAINZ_RELEASE_STATUS,
//   MUSICBRAINZ_RELEASE_TRACK_ID,
//   MUSICBRAINZ_RELEASE_TYPE,
//   MUSICBRAINZ_TRACK_ID,
//   MUSICBRAINZ_WORK_ID,
//   MUSICIP_ID,
//   OCCASION,
//   REMIXER,
//   SCRIPT,
//   TITLE_SORT,
//   TRACK_TOTAL,
//   URL_DISCOGS_ARTIST_SITE,
//   URL_DISCOGS_RELEASE_SITE,
//   URL_LYRICS_SITE,
//   URL_OFFICIAL_ARTIST_SITE,
//   URL_OFFICIAL_RELEASE_SITE,
//   URL_WIKIPEDIA_ARTIST_SITE,
//   URL_WIKIPEDIA_RELEASE_SITE,
// }
